==> AsposeCellsCloud-CellsApi-25.6.1.tar.gz: AsposeCellsCloud-CellsApi-25.6.1/docs/model/DataBar.md <==
# AsposeCellsCloud::Object::DataBar 

## Load the model package
```perl
use AsposeCellsCloud::Object::DataBar;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AxisColor** | **Color** | Gets the color of the axis for cells with conditional formatting as data bars.  |
**AxisPosition** | **string** | Gets or sets the position of the axis of the data bars specified by a conditional formatting rule.  |
**BarBorder** | **DataBarBorder** | Gets an object that specifies the border of a data bar.  |
**BarFillType** | **string** | Gets or sets how a data bar is filled with color.  |
**Color** | **Color** | Get or set this DataBar's Color.  |
**Direction** | **string** | Gets or sets the direction the databar is displayed.  |
**MaxCfvo** | **ConditionalFormattingValue** | Get or set this DataBar's max value object.            Cannot set null or CFValueObject with type FormatConditionValueType.Min to it.  |
**MaxLength** | **int** | Represents the max length of data bar .  |
**MinCfvo** | **ConditionalFormattingValue** | Get or set this DataBar's min value object.            Cannot set null or CFValueObject with type FormatConditionValueType.Max to it.  |
**MinLength** | **int** | Represents the min length of data bar .  |
**NegativeBarFormat** | **NegativeBarFormat** | Gets the NegativeBarFormat object associated with a data bar conditional formatting rule.  |
**ShowValue** | **boolean** | Get or set the flag indicating whether to show the values of the cells on which this data bar is applied.            Default value is true.  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/DataBar.md <==
# AsposeCellsCloud::Object::DataBar 

## Load the model package
```perl
use AsposeCellsCloud::Object::DataBar;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**AxisColor** | **Color** | Gets the color of the axis for cells with conditional formatting as data bars.  |
**AxisPosition** | **string** | Gets or sets the position of the axis of the data bars specified by a conditional formatting rule.  |
**BarBorder** | **DataBarBorder** | Gets an object that specifies the border of a data bar.  |
**BarFillType** | **string** | Gets or sets how a data bar is filled with color.  |
**Color** | **Color** | Get or set this DataBar's Color.  |
**Direction** | **string** | Gets or sets the direction the databar is displayed.  |
**MaxCfvo** | **ConditionalFormattingValue** | Get or set this DataBar's max value object.            Cannot set null or CFValueObject with type FormatConditionValueType.Min to it.  |
**MaxLength** | **int** | Represents the max length of data bar .  |
**MinCfvo** | **ConditionalFormattingValue** | Get or set this DataBar's min value object.            Cannot set null or CFValueObject with type FormatConditionValueType.Max to it.  |
**MinLength** | **int** | Represents the min length of data bar .  |
**NegativeBarFormat** | **NegativeBarFormat** | Gets the NegativeBarFormat object associated with a data bar conditional formatting rule.  |
**ShowValue** | **boolean** | Get or set the flag indicating whether to show the values of the cells on which this data bar is applied.            Default value is true.  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
